Are you liking **Typer**?

Would you like to help Typer, other users, and the author?

Or would you like to get help with **Typer**?

There are very simple ways to help (several involve just one or two clicks).

And there are several ways to get help too.

## Star **Typer** in GitHub

You can "star" Typer in GitHub (clicking the star button at the top right): <a href="https://github.com/alexreg/typer-cloup" class="external-link" target="_blank">https://github.com/alexreg/typer-cloup</a>.

By adding a star, other users will be able to find it more easily and see that it has been already useful for others.

## Watch the GitHub repository for releases

You can "watch" Typer in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/alexreg/typer-cloup" class="external-link" target="_blank">https://github.com/alexreg/typer-cloup</a>.

There you can select "Releases only".

Doing it, you will receive notifications (in your email) whenever there's a new release (a new version) of **Typer** with bug fixes and new features.

## Help others with issues in GitHub

You can see <a href="https://github.com/alexreg/typer-cloup/issues" class="external-link" target="_blank">existing issues</a> and try and help others.

## Watch the GitHub repository

You can "watch" Typer in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/alexreg/typer-cloup" class="external-link" target="_blank">https://github.com/alexreg/typer-cloup</a>.

If you select "Watching" instead of "Releases only", you will receive notifications when someone creates a new issue.

Then you can try and help them solving those issues.

## Create issues

You can <a href="https://github.com/alexreg/typer-cloup/issues/new/choose" class="external-link" target="_blank">create a new issue</a> in the GitHub repository, for example to:

* Report a bug/issue.
* Suggest a new feature.
* Ask a question.

## Create a Pull Request

You can <a href="https://github.com/alexreg/typer-cloup" class="external-link" target="_blank">create a Pull Request</a>, for example:

* To fix a typo you found on the documentation.
* To propose new documentation sections.
* To fix an existing issue/bug.
* To add a new feature.


## Sponsor the tools that power Typer

As you have seen in the documentation, Typer is built on top of Click.

You can also sponsor:

* Pallets Project (Click maintainers)<a href="https://palletsprojects.com/donate" class="external-link" target="_blank">via the PSF</a> or <a href="https://tidelift.com/subscription/pkg/pypi-click" class="external-link" target="_blank">via Tidelift</a>

---

Thanks! 🚀
